==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEvaluationPlanTipificationInteractionTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanTipificationInteractionTask] (
    @VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL -- EVALUATION PLAN ID
)
AS
BEGIN
SET NOCOUNT ON
	-- ESTE SP TIENE POR FINALIDAD RETORNAR LA LISTA DE INTERACCIONES CRUZADA CON LOS MODELOS NLU PARA TIPIFICACIONES QUE SE VAN A EVALUAR

	-- DECLARAMOS UNA VARIABLE PARA DEFINIR EL TAMANO DE CAMPO NUEVO EN LA TABLA TEMPORAL
	DECLARE @MAIN_TARGET VARCHAR(50) = 'ABILITY' 
	
	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN Y LAS HABILIDADES QUE LO APLICAN
	SELECT DISTINCT HAQ.VCC										'vcc'
					,N.[Name] + '|' + I.[Name]					'cognitiveId'
					,N.[Name]									'nluId'
					,N.[AppId]									'appId'
					,I.[IntentId]								'intentId'
					,@MAIN_TARGET								'mainTarget'
					,STUFF(
						(
							SELECT DISTINCT ',' + INNER_HAQ.[AbilityId]
								FROM [dbo].[HistoricAbilityQuery] INNER_HAQ (NOLOCK)
								WHERE INNER_HAQ.[VCC] = HAQ.[VCC]
									AND INNER_HAQ.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
									AND INNER_HAQ.[QueryContent] = N.[Name] + '|' + I.[Name]
							FOR XML PATH(''), TYPE
						).value('.', 'NVARCHAR(MAX)'), 
						1, 
						1, 
						''
					)											'abilities'
					,CONVERT(BIT, 1) 							'needRequest'
		INTO #EVALUATION_PLAN_MODELS 
		FROM [HistoricAbilityQuery] HAQ (NOLOCK) 
		INNER JOIN [HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = HAQ.[VCC]
				AND HA.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
				AND HA.[ID] = HAQ.[AbilityId]
		INNER JOIN [dbo].[Intent] I (NOLOCK)
			ON I.[VCC] = HAQ.[VCC]
				AND I.[IntentId] = HAQ.[QueryId]
		INNER JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = HAQ.[VCC]
				AND N.[AppId] = I.[AppId]
		WHERE HAQ.[VCC] = @VCC
			AND HAQ.[EvaluationPlanId] = @EvaluationPlanId
			AND HA.[AnalysisType] = 'COGNITIVE'

	-- DROP TABLE #EVALUATION_PLAN_MODELS 
	-- SELECT * FROM #EVALUATION_PLAN_MODELS 

	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN (TIPIFICACIONES) QUE NO EXISTEN EN LAS HABILIDADES
	INSERT INTO #EVALUATION_PLAN_MODELS 
		SELECT DISTINCT HEFASTQ.VCC								'vcc'
						,N.[Name] + '|' + I.[Name]				'cognitiveId'
						,N.[Name]								'nluId'
						,N.[AppId]								'appId'
						,I.[IntentId]							'intentId'
						,'TIPIFICATION'							'mainTarget'
						,STUFF(
							(
								SELECT DISTINCT ',' + INNER_HS.[IdAbility]
									FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] INNER_HEFASTQ (NOLOCK)
									INNER JOIN [dbo].[HistoricScore] INNER_HS (NOLOCK)
										ON INNER_HS.[VCC] = INNER_HEFASTQ.[VCC]
											AND INNER_HS.[EvaluationPlanId] = INNER_HEFASTQ.[EvaluationPlanId]
											AND INNER_HS.[ID] = INNER_HEFASTQ.[ScoreId]
									WHERE INNER_HEFASTQ.[VCC] = HEFASTQ.[VCC]
										AND INNER_HEFASTQ.[EvaluationPlanId] = HEFASTQ.[EvaluationPlanId]
										AND INNER_HEFASTQ.[QueryContent] = N.[Name] + '|' + I.[Name]
								FOR XML PATH(''), TYPE
							).value('.', 'NVARCHAR(MAX)'), 
							1, 
							1, 
							''
						)										'abilities'
						,CASE WHEN EPM.[vcc] IS NULL 
								THEN CONVERT(BIT, 1)
								ELSE CONVERT(BIT, 0)
							END									'needRequest'
			FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] HEFASTQ (NOLOCK)
			INNER JOIN [dbo].[HistoricScore] HS (NOLOCK)
				ON HS.[VCC] = HEFASTQ.[VCC]
					AND HS.[EvaluationPlanId] = HEFASTQ.[EvaluationPlanId]
					AND HS.[ID] = HEFASTQ.[ScoreId]
			INNER JOIN [dbo].[Intent] I (NOLOCK)
				ON I.[VCC] = HEFASTQ.[VCC]
					AND I.[IntentId] = HEFASTQ.[QueryId]
			INNER JOIN [dbo].[NLU] N (NOLOCK)
				ON N.[VCC] = HEFASTQ.[VCC]
					AND N.[AppId] = I.[AppId]
			LEFT JOIN #EVALUATION_PLAN_MODELS EPM (NOLOCK)
				ON EPM.[VCC] = HEFASTQ.[VCC]
					AND EPM.[appId] = N.[AppId]
					AND EPM.[intentId] = I.[IntentId]
			WHERE HEFASTQ.[VCC] = @VCC
				AND HEFASTQ.[EvaluationPlanId] = @EvaluationPlanId



	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO CALL QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AU.Campaign								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,AU.Section									'section'
			,AU.Part									'part'
			,NULL										'folder'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AU.[FileName]								'fileName'
			--,EPM.[cognitiveId]						-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON IEP.Instance = EP.Instance 
			AND IEP.IdEvaluationPlan = EP.Id
	INNER JOIN [dbo].[Audio] AU (NOLOCK) 
		ON AU.VCC = EP.Instance
			AND AU.ID = IEP.IdInteraction 
	INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
		ON ER.[Instance] = EP.[Instance]
			AND ER.[IdEvaluationPlan] = EP.[ID]
			AND ER.[IdInteraction] = AU.[ID]
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @EvaluationPlanId
		AND AU.[IsTranscribed] = 1
		AND ER.[Qualification] = 0
		AND EPM.[mainTarget] = 'TIPIFICATION'
	
	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO TEXT QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AI.[Campaign]								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,NULL										'section'
			,NULL										'part'
			,AI.[EndDate]								'endDate'
			,AI.[Folder]								'folder'
			,AI.[DispositionCode]						'dispositionCode'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AI.[FileName]								'fileName'
			--,F.[cognitiveId]							-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON EP.Instance = IEP.Instance 
			AND EP.Id = IEP.IdEvaluationPlan
	INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK) 
		ON EP.Instance = AI.VCC 
			AND IEP.IdInteraction = AI.ID
			AND IEP.FormattedEndDate = AI.Folder
	INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
		ON ER.[Instance] = EP.[Instance]
			AND ER.[IdEvaluationPlan] = EP.[ID]
			AND ER.[IdInteraction] = AI.[ID]
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @EvaluationPlanId
		AND AI.[IsTranscribed] = 1
		AND ER.[Qualification] = 0
		AND EPM.[mainTarget] = 'TIPIFICATION'

SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.6.3_database.tar.gz: database/mssql/procedures/GetEvaluationPlanTipificationInteractionTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanTipificationInteractionTask] (
    @VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL -- EVALUATION PLAN ID
)
AS
BEGIN
SET NOCOUNT ON
	-- ESTE SP TIENE POR FINALIDAD RETORNAR LA LISTA DE INTERACCIONES CRUZADA CON LOS MODELOS NLU PARA TIPIFICACIONES QUE SE VAN A EVALUAR

	-- DECLARAMOS UNA VARIABLE PARA DEFINIR EL TAMANO DE CAMPO NUEVO EN LA TABLA TEMPORAL
	DECLARE @MAIN_TARGET VARCHAR(50) = 'ABILITY' 
	
	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN Y LAS HABILIDADES QUE LO APLICAN
	SELECT DISTINCT HAQ.VCC										'vcc'
					,N.[Name] + '|' + I.[Name]					'cognitiveId'
					,N.[Name]									'nluId'
					,N.[AppId]									'appId'
					,I.[IntentId]								'intentId'
					,@MAIN_TARGET								'mainTarget'
					,STUFF(
						(
							SELECT DISTINCT ',' + INNER_HAQ.[AbilityId]
								FROM [dbo].[HistoricAbilityQuery] INNER_HAQ (NOLOCK)
								WHERE INNER_HAQ.[VCC] = HAQ.[VCC]
									AND INNER_HAQ.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
									AND INNER_HAQ.[QueryContent] = N.[Name] + '|' + I.[Name]
							FOR XML PATH(''), TYPE
						).value('.', 'NVARCHAR(MAX)'), 
						1, 
						1, 
						''
					)											'abilities'
					,CONVERT(BIT, 1) 							'needRequest'
		INTO #EVALUATION_PLAN_MODELS 
		FROM [HistoricAbilityQuery] HAQ (NOLOCK) 
		INNER JOIN [HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = HAQ.[VCC]
				AND HA.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
				AND HA.[ID] = HAQ.[AbilityId]
		INNER JOIN [dbo].[Intent] I (NOLOCK)
			ON I.[VCC] = HAQ.[VCC]
				AND I.[IntentId] = HAQ.[QueryId]
		INNER JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = HAQ.[VCC]
				AND N.[AppId] = I.[AppId]
		WHERE HAQ.[VCC] = @VCC
			AND HAQ.[EvaluationPlanId] = @EvaluationPlanId
			AND HA.[AnalysisType] = 'COGNITIVE'

	-- DROP TABLE #EVALUATION_PLAN_MODELS 
	-- SELECT * FROM #EVALUATION_PLAN_MODELS 

	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN (TIPIFICACIONES) QUE NO EXISTEN EN LAS HABILIDADES
	INSERT INTO #EVALUATION_PLAN_MODELS 
		SELECT DISTINCT HEFASTQ.VCC								'vcc'
						,N.[Name] + '|' + I.[Name]				'cognitiveId'
						,N.[Name]								'nluId'
						,N.[AppId]								'appId'
						,I.[IntentId]							'intentId'
						,'TIPIFICATION'							'mainTarget'
						,STUFF(
							(
								SELECT DISTINCT ',' + INNER_HS.[IdAbility]
									FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] INNER_HEFASTQ (NOLOCK)
									INNER JOIN [dbo].[HistoricScore] INNER_HS (NOLOCK)
										ON INNER_HS.[VCC] = INNER_HEFASTQ.[VCC]
											AND INNER_HS.[EvaluationPlanId] = INNER_HEFASTQ.[EvaluationPlanId]
											AND INNER_HS.[ID] = INNER_HEFASTQ.[ScoreId]
									WHERE INNER_HEFASTQ.[VCC] = HEFASTQ.[VCC]
										AND INNER_HEFASTQ.[EvaluationPlanId] = HEFASTQ.[EvaluationPlanId]
										AND INNER_HEFASTQ.[QueryContent] = N.[Name] + '|' + I.[Name]
								FOR XML PATH(''), TYPE
							).value('.', 'NVARCHAR(MAX)'), 
							1, 
							1, 
							''
						)										'abilities'
						,CASE WHEN EPM.[vcc] IS NULL 
								THEN CONVERT(BIT, 1)
								ELSE CONVERT(BIT, 0)
							END									'needRequest'
			FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] HEFASTQ (NOLOCK)
			INNER JOIN [dbo].[HistoricScore] HS (NOLOCK)
				ON HS.[VCC] = HEFASTQ.[VCC]
					AND HS.[EvaluationPlanId] = HEFASTQ.[EvaluationPlanId]
					AND HS.[ID] = HEFASTQ.[ScoreId]
			INNER JOIN [dbo].[Intent] I (NOLOCK)
				ON I.[VCC] = HEFASTQ.[VCC]
					AND I.[IntentId] = HEFASTQ.[QueryId]
			INNER JOIN [dbo].[NLU] N (NOLOCK)
				ON N.[VCC] = HEFASTQ.[VCC]
					AND N.[AppId] = I.[AppId]
			LEFT JOIN #EVALUATION_PLAN_MODELS EPM (NOLOCK)
				ON EPM.[VCC] = HEFASTQ.[VCC]
					AND EPM.[appId] = N.[AppId]
					AND EPM.[intentId] = I.[IntentId]
			WHERE HEFASTQ.[VCC] = @VCC
				AND HEFASTQ.[EvaluationPlanId] = @EvaluationPlanId



	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO CALL QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AU.Campaign								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,AU.Section									'section'
			,AU.Part									'part'
			,NULL										'folder'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AU.[FileName]								'fileName'
			--,EPM.[cognitiveId]						-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON IEP.Instance = EP.Instance 
			AND IEP.IdEvaluationPlan = EP.Id
	INNER JOIN [dbo].[Audio] AU (NOLOCK) 
		ON AU.VCC = EP.Instance
			AND AU.ID = IEP.IdInteraction 
	INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
		ON ER.[Instance] = EP.[Instance]
			AND ER.[IdEvaluationPlan] = EP.[ID]
			AND ER.[IdInteraction] = AU.[ID]
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	INNER JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @EvaluationPlanId
		AND AU.[IsTranscribed] = 1
		AND ER.[Qualification] = 0
		AND EPM.[mainTarget] = 'TIPIFICATION'
	
	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO TEXT QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AI.[Campaign]								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,NULL										'section'
			,NULL										'part'
			,AI.[EndDate]								'endDate'
			,AI.[Folder]								'folder'
			,AI.[DispositionCode]						'dispositionCode'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AI.[FileName]								'fileName'
			--,F.[cognitiveId]							-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON EP.Instance = IEP.Instance 
			AND EP.Id = IEP.IdEvaluationPlan
	INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK) 
		ON EP.Instance = AI.VCC 
			AND IEP.IdInteraction = AI.ID
			AND IEP.FormattedEndDate = AI.Folder
	INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
		ON ER.[Instance] = EP.[Instance]
			AND ER.[IdEvaluationPlan] = EP.[ID]
			AND ER.[IdInteraction] = AI.[ID]
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	INNER JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @EvaluationPlanId
		AND AI.[IsTranscribed] = 1
		AND ER.[Qualification] = 0
		AND EPM.[mainTarget] = 'TIPIFICATION'

SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
